@@ -2,6 +2,6 @@ from __future__ import generator_stop
 
 
 def _filemanager_cmd_mac(path):
-	# type: (str, ) -> str
+    # type: (str, ) -> str
 
-	return 'open -R "{}"'.format(path)
+    return f'open -R "{path}"'
